@@ -34,7 +34,9 @@ class TeeInput(object):
         self._is_socket = True
         self._len = parser.content_len
         
-        if self._len and self._len < util.MAX_BODY:
+        if not self.parser.content_len and not self.parser.is_chunked:
+            self.tmp = StringIO()
+        elif self._len and self._len < util.MAX_BODY:
             self.tmp = StringIO()
         else:
             self.tmp = tempfile.TemporaryFile(dir=self.conf['tmp_upload_dir'])
@@ -148,7 +150,10 @@ class TeeInput(object):
     __next__ = next
     
     def __iter__(self):
-        return self    
+        return self
+        
+    def get_socket(self):
+        return self._sock.dup()    
 
     def _tee(self, length):
         """ fetch partial body"""
