@@ -93,7 +93,15 @@ class Worker(object):
         util.close_on_exec(self.socket)
         util.close_on_exec(self.fd)
         self.init_signals()
-        
+    
+    def accept(self):
+        try:
+            client, addr = self.socket.accept()
+            self.handle(client, addr)
+            self.nr += 1
+        except socket.error, e:
+            if e[0] not in (errno.EAGAIN, errno.ECONNABORTED):
+                raise
     
     def run(self):
         self.init_process()
@@ -106,13 +114,9 @@ class Worker(object):
         while self.alive:
             self.nr = 0
             self.notify()
-            try:
-                client, addr = self.socket.accept()
-                self.handle(client, addr)
-                self.nr += 1
-            except socket.error, e:
-                if e[0] not in (errno.EAGAIN, errno.ECONNABORTED):
-                    raise
+            
+            # accept a new connection
+            self.accept()
 
             # Keep processing clients until no one is waiting.
             # This prevents the need to select() for every
